@@ -108,6 +108,10 @@ class Selenese(object):
     def open(self, url, ignoreResponseCode=True):
         self.selenium.do_command("open", [url, ignoreResponseCode])
 
+    @passthrough
+    def selectWindow(self, name):
+        pass
+
     @passthrough
     def addCustomRequestHeader(self, key, value):
         pass
@@ -406,6 +410,18 @@ class Selenese(object):
                 'No alert occured.')
         return self.selenium.get_alert()
 
+    @passthrough
+    def getAllWindowIds(self):
+        pass
+
+    @passthrough
+    def getAllWindowNames(self):
+        pass
+
+    @passthrough
+    def getAllWindowTitles(self):
+        pass
+
     @assert_type('locator_pattern')
     @passthrough
     def getAttribute(self, locator):
